%if 0%{?fedora} || 0%{?rhel} > 7
# Enable python3 build by default
%bcond_without python3
%else
%bcond_with python3
%endif

%if 0%{?suse_version}
  %define libdw_devel libdw-devel
  %define libelf_devel libelf-devel
%else
  %define libdw_devel elfutils-devel
  %define libelf_devel elfutils-libelf-devel
%endif

%define glib_ver 2.43.4

Name: satyr
Version: 0.37.2.gc812
Release: 1%{?dist}
Summary: Tools to create anonymous, machine-friendly problem reports
License: GPLv2+
URL: https://github.com/abrt/satyr
Source0: https://github.com/abrt/%{name}/releases/download/%{version}/%{name}-%{version}.tar.gz
%if %{with python3}
BuildRequires: python3-devel
%endif
BuildRequires: %{libdw_devel}
BuildRequires: %{libelf_devel}
BuildRequires: binutils-devel
BuildRequires: rpm-devel
BuildRequires: libtool
BuildRequires: doxygen
BuildRequires: pkgconfig
BuildRequires: make
BuildRequires: automake
BuildRequires: gcc-c++
BuildRequires: gdb
BuildRequires: gperf
BuildRequires: nettle-devel%{?_isa}
BuildRequires: json-c-devel%{?_isa}
BuildRequires: glib2-devel%{?_isa}
%if %{with python3}
BuildRequires: python3-sphinx
%endif
Requires: json-c%{?_isa}
Requires: nettle%{?_isa}
Requires: glib2%{?_isa} >= %{glib_ver}

%description
Satyr is a library that can be used to create and process microreports.
Microreports consist of structured data suitable to be analyzed in a fully
automated manner, though they do not necessarily contain sufficient information
to fix the underlying problem. The reports are designed not to contain any
potentially sensitive data to eliminate the need for review before submission.
Included is a tool that can create microreports and perform some basic
operations on them.

%package devel
Summary: Development libraries for %{name}
Requires: %{name}%{?_isa} = %{version}-%{release}

%description devel
Development libraries and headers for %{name}.

%if %{with python3}
%package -n python3-satyr
%{?python_provide:%python_provide python3-satyr}
Summary: Python 3 bindings for %{name}
Requires: %{name}%{?_isa} = %{version}-%{release}

%description -n python3-satyr
Python 3 bindings for %{name}.
%endif

%prep
%setup -q

%build
autoreconf

%configure \
%if %{without python3}
        --without-python3 \
%endif
        --disable-static \
        --enable-doxygen-docs

%make_build

%install
%make_install

# Remove all libtool archives (*.la) from modules directory.
find %{buildroot} -name "*.la" -delete

%check
make check|| {
    # find and print the logs of failed test
    # do not cat tests/testsuite.log because it contains a lot of bloat
    cat tests/test-suite.log
    find tests/testsuite.dir -name "testsuite.log" -print -exec cat '{}' \;
    exit 1
}

%if 0%{?fedora} > 27
# ldconfig is not needed
%else
%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%endif

%files
%doc README.md NEWS
%license COPYING
%{_bindir}/satyr
%{_mandir}/man1/%{name}.1*
%{_libdir}/lib*.so.*

%files devel
# The complex pattern below (instead of simlpy *) excludes Makefile{.am,.in}:
%doc apidoc/html/*.{html,png,css,js}
%{_includedir}/*
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*

%if 0%{?with_python3}
%files -n python3-satyr
%dir %{python3_sitearch}/%{name}
%{python3_sitearch}/%{name}/*
%endif

%changelog
* Tue Mar 02 2021 Michal Fabik <mfabik@redhat.com> 0.37-1
- sr_distances_cluster_objects: Check arg safety
- spec: Drop trailing comment

* Tue Jan 12 2021 Michal Fabik <mfabik@redhat.com> 0.36-1
- spec: Use autoreconf in %build

* Tue Dec 01 2020 Michal Fabik <mfabik@redhat.com> 0.35-1
- BR make

* Mon Nov 30 2020 Michal Fabik <mfabik@redhat.com> 0.34-1
- tests: Drop unused var

* Mon Nov 30 2020 Michal Fabik <mfabik@redhat.com> 0.33-1
- tests: Don't pass va_list as function argument
- spec: Output logs from failed tests
- tests: Use correct format specifier for size_t
- spec: Don't use GitHub-generated tarball as Source

* Tue Nov 24 2020 Michal Fabik <mfabik@redhat.com> 0.32-1
- README: Add instructions for contributing
- Add a commit message template
- tests: Don't _FORTIFY_SOURCE for dump_core.c
- tests: Fix compiler warnings
- NEWS: Update unreleased changes
- report: Fix leak
- koops_stacktrace: Copy and free modules too
- koops_stacktrace: Fix leak
- tests: Fix leaks
- test: Remove unused generate_coredump
- tests: Reintroduce dendrogram_cut test
- tests: Finish moving away from Autotest
- tests: Replace sr_strdup with g_strdup
- tests: Replace sr_asprintf with g_strdup_printf
- tests: Replace sr_strbuf with GString
- tests: Move away from Autotest
- spec, Makefile, RELEASE: README -> README.md
- README: Add building instructions
- Replace sr_strcmp0 with g_strcmp0
- Replace sr_strdup with g_strdup
- Replace sr_strndup with g_strndup
- Replace sr_vasprintf with g_strdup_vprintf
- Replace sr_asprintf with g_strdup_printf
- Replace sr_realloc with g_realloc
- Replace sr_malloc with g_malloc
- Replace sr_mallocz with g_malloc0
- Replace sr_realloc_array with g_realloc_n
- Replace sr_malloc_array with g_malloc_n
- Replace sr_strbuf with GString
- Add dependency on GLib
- lib: abrt: Drop references to fingerprinting

* Tue Aug 18 2020 Michal Fabik <mfabik@redhat.com> 0.31-1
- Bump version-info before new release
- spec: Make some dependencies architecture-dependent
- Add GitHub Actions workflow for building PRs
- autogen.sh: Pass --assumeyes to DNF
- Remove #define PyString_AsString PyUnicode_AsUTF8
- Fix -Wdiscarded-qualifiers warning
- python: Adapt to changes made in PEP 590
- tests: ruby_frame: Drop return

* Mon Feb 03 2020 Ernestas Kulik <ekulik@redhat.com> 0.30-1
- Fix build failure with gcc -fno-common
- lib: Remove superfluous includes
- lib: Use Nettle for computing SHA-1 digests
- lib: core_stacktrace: Plug leak
- lib: koops_stacktrace: Don’t parse register as module

* Fri Oct 11 2019 Matěj Grabovský <mgrabovs@redhat.com> 0.29-1
- spec: Switch sources tarball compression from xz to gzip
- spec: Replace xargs rm with delete
- spec: Remove provides for satyr-python3
- spec: Replace make with rpm macros
- Replace bundled JSON parser with json-c
- lib: normalize: Hash removable function names
- rpm: Fix typo in a static function name
- json: Improve error messages on EOF
- json: Use backticks consistently in error messages
- json,style: Improve code style consistency slightly
- json: Update to latest upstream version
- core: Document unknown core frame address
- style: Correct parenthesization for bitfield tests
- style: Use specific integer types instead of the generic int
- style: Use *_MAX constants instead of -1 in unsigned comparisons

* Fri Jun 21 2019 Ernestas Kulik <ekulik@redhat.com> 0.28-1
- Release version 0.28

* Fri Oct 05 2018 Martin Kutlak <mkutlak@redhat.com> 0.27-1
- Improve truncated backtrace format for python and core
- Anonymize paths in frames

* Tue Apr 17 2018 Matej Habrnal <mhabrnal@redhat.com> 0.26-1
- spec: fix Allow python2 to be optional at build time
- python: Allow python2 to be optional at build time
- configure: use PKG_PROG_PKG_CONFIG to detect pkg-config
- makefile: add RPM_FLAGS variable to rpmbuild
- Allow python2 to be optional at build time
- autogen: correctly parse buildrequires from spec file
- normalization: actualize list of functions
- Append Python interpreter as related package
- spec: Update Python 2 dependency declarations
- makefile: create .tar.xz with make release
- remove 2+ years old changelog entries
- remove Groups
- we do not build for el6 any more
- mark license as license
- ldconfig is not needed in rawhide

* Thu Jan 18 2018 Martin Kutlak <mkutlak@redhat.com> 0.25-1
- New upstream version
 - Normalization: actualize list of functions
 - Fix some compilation warnings
 - Allow to build python3 for rhel8
 - Makefile: add make release-* subcommands
 - Elfutils: Add missing stubs from earlier commit

* Wed Nov 1 2017 Julius Milan <jmilan@redhat.com> 0.24-1
- New upstream version
  - Allow to report unpackaged problems
  - apidoc: generate html docs using doxygen
  - Fix parsing of subset of arm kernel oopses

* Mon Mar 13 2017 Matej Habrnal <mhabrnal@redhat.com> 0.23-1
- New upstream version
  - Allow rpm to be optional at build time
  - Do not use deprecated fedorahosted.org

* Thu Dec 1 2016 Jakub Filak <jakub@thefilaks.net> 0.22-1
- New upstream version
  - Added support fof JavaScript (V8) stack traces
  - Most parts of the in-hook core unwinder callable under unprivileged user
  - GDB core unwinder limits number of unwound frames
  - Fixed a pair of compile warnings - Chris Redmon <credmonster@gmail.com>

* Wed May 18 2016 Matej Habrnal <mhabrnal@redhat.com> 0.21-1
- New upstream version
  - Introduce 'serial' field in uReport
  - normalization: actualize list of functions
